@@ -122,9 +122,13 @@ details',
           'config_class_name' => 'Dpkg::Install',
           'type' => 'node'
         },
-        'description' => 'List the files to install into each package and the directory they should be installed to.
+        'description' => '=pod
 
-Here the mapping between the install files and the install key:
+List the files to install into each package and the directory they
+should be installed to.
+
+Here\'s the mapping between the debian install files and the install
+key:
 
 '.'=over 4
 
@@ -140,6 +144,10 @@ Here the mapping between the install files and the install key:
 
 "package/arch" -> C<debian/package.install.arch>
 
+'.'=item *
+
+"package.docs" -> C<debian/package.docs>
+
 '.'=back
 
 ',
