@@ -192,11 +192,11 @@ $_ = $str ? \'autopkgtest-pkg-\'.$str : undef;',
           }
         },
         'warn_unless_match' => {
-          '^autopkgtest(-pkg-(dkms|elpa|go|nodejs|octave|perl|python|r|ruby))?$' => {
+          '^autopkgtest(-pkg-(dkms|elpa|go|nodejs|octave|perl|pybuild|python|r|ruby))?$' => {
             'fix' => 'my $m = $self->grab_value(\'- Maintainer\');
 my ($str) = ($m =~ /pkg-(perl|ruby|go)/);
 $_ = $str ? \'autopkgtest-pkg-\'.$str : undef;',
-            'msg' => 'Unknown value'
+            'msg' => 'Testsuite $_ is not a known automatic test suite'
           }
         }
       },
@@ -237,18 +237,18 @@ in Debian developer reference.',
         ],
         'default' => 'optional',
         'help' => {
-            'extra' => 'This contains all packages that conflict with others with required, important, standard or optional priorities, or are only likely to be useful
+          'extra' => 'This contains all packages that conflict with others with required, important, standard or optional priorities, or are only likely to be useful
 if you already know what they are or have specialized requirements (such as packages containing only detached debugging symbols).',
-            'important' => 'Important programs, including those which one would expect to find on any Unix-like system. If the expectation is that an experienced Unix person
+          'important' => 'Important programs, including those which one would expect to find on any Unix-like system. If the expectation is that an experienced Unix person
 who found it missing would say "What on earth is going on, where is foo?", it must be an important package.[5] Other packages without which the system will not run well or
 be usable must also have priority important. This does not include Emacs, the X Window System, TeX or any other large applications. The important packages are just a bare minimum of commonly-expected and necessary tools.',
-            'optional' => '(In a sense everything that isn\'t required is optional, but that\'s not what is meant here.) This is all the software that you might reasonably
+          'optional' => '(In a sense everything that isn\'t required is optional, but that\'s not what is meant here.) This is all the software that you might reasonably
 want to install if you didn\'t know what it was and don\'t have specialized requirements. This is a much larger system and includes the X Window System, a full TeX distribution, and many applications.
 Note that optional packages should not conflict with each other. ',
-            'required' => 'Packages which are necessary for the proper functioning of the system (usually, this means that dpkg functionality depends on these packages).
+          'required' => 'Packages which are necessary for the proper functioning of the system (usually, this means that dpkg functionality depends on these packages).
 Removing a required package may cause your system to become totally broken and you may not even be able to use dpkg to put things back, so only do so if you know what you are doing.
 Systems with only the required packages are probably unusable, but they do have enough functionality to allow the sysadmin to boot and install more software. ',
-            'standard' => 'These packages provide a reasonably small but not too limited character-mode system. This is what will be installed by default if the user doesn\'t
+          'standard' => 'These packages provide a reasonably small but not too limited character-mode system. This is what will be installed by default if the user doesn\'t
 select anything else. It doesn\'t include many large applications. '
         },
         'type' => 'leaf',
@@ -503,7 +503,7 @@ The information is meant to be useful for the final user, willing to browse the
       },
       'Vcs-Arch',
       {
-          'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
+        'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
 if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial),
 mtn (Monotone), svn (Subversion). It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
 
@@ -524,7 +524,7 @@ anonymous access of the repository instead of pointing to an SSH-accessible vers
       },
       'Vcs-Bzr',
       {
-          'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
+        'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
 if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial),
 mtn (Monotone), svn (Subversion). It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
 
@@ -546,7 +546,7 @@ of pointing to an SSH-accessible version of the same. ',
       },
       'Vcs-Cvs',
       {
-          'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
+        'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
 if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial),
 mtn (Monotone), svn (Subversion). It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
 
@@ -567,7 +567,7 @@ Also, the location pointed to should be accessible to the final user; fulfilling
       },
       'Vcs-Darcs',
       {
-          'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
+        'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
 if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion).
 It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
 
@@ -629,7 +629,7 @@ Also, the location pointed to should be accessible to the final user; fulfilling
       },
       'Vcs-Hg',
       {
-          'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
+        'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
 if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion).
 It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
 
@@ -650,7 +650,7 @@ Also, the location pointed to should be accessible to the final user; fulfilling
       },
       'Vcs-Mtn',
       {
-          'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
+        'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
 if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion).
 It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
 
@@ -664,7 +664,7 @@ Also, the location pointed to should be accessible to the final user; fulfilling
       },
       'Vcs-Svn',
       {
-          'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
+        'description' => 'Value of this field should be a string identifying unequivocally the location of the Version Control System repository used to maintain the given package,
 if available. * identify the Version Control System; currently the following systems are supported by the package tracking system: arch, bzr (Bazaar), cvs, darcs, git, hg (Mercurial), mtn (Monotone), svn (Subversion).
 It is allowed to specify different VCS fields for the same package: they will all be shown in the PTS web interface.
 
@@ -685,7 +685,7 @@ Also, the location pointed to should be accessible to the final user; fulfilling
       },
       'DM-Upload-Allowed',
       {
-          'description' => 'If this field is present, then any Debian Maintainers listed in the Maintainer or Uploaders fields may upload the package directly to the Debian archive.
+        'description' => 'If this field is present, then any Debian Maintainers listed in the Maintainer or Uploaders fields may upload the package directly to the Debian archive.
 For more information see the "Debian Maintainer" page at the Debian Wiki - https://wiki.debian.org/DebianMaintainer',
         'match' => 'yes',
         'status' => 'deprecated',
@@ -700,15 +700,15 @@ For more information see the "Debian Maintainer" page at the Debian Wiki - https
       },
       'Rules-Requires-Root',
       {
-          'description' => 'Depending on the value of the Rules-Requires-Root field, the package builder (e.g. dpkg-buildpackage) may run the debian/rules target as an unprivileged user and provide a gain root command.
+        'description' => 'Depending on the value of the Rules-Requires-Root field, the package builder (e.g. dpkg-buildpackage) may run the debian/rules target as an unprivileged user and provide a gain root command.
 This command allows the debian/rules target to run particular subcommands under (fake)root. Can be \'no\', \'binary-targets\' (default)), or a space separated list of keywords containing a forward slash (e.g. "/").
 
 For details, see L<section 5.6.31.2 of Debian policy|https://www.debian.org/doc/debian-policy/ch-controlfields.html#rules-requires-root>',
         'help' => {
-            '.+/' => 'Space separated list of keywords. These keywords must always contain a forward slash, which sets them apart from the other possible values of Rules-Requires-Root.
+          '.+/' => 'Space separated list of keywords. These keywords must always contain a forward slash, which sets them apart from the other possible values of Rules-Requires-Root.
 When this list is provided, the builder must provide a gain root command (as defined in debian/rules and Rules-Requires-Root) or pretend that the value was set to binary-targets,
 and both the builder and the package’s debian/rules script must downgrade accordingly.',
-            'binary-targets' => '(Default) Declares that the package will need the root (or fakeroot) when either of the binary, binary-arch or binary-indep targets are called.
+          'binary-targets' => '(Default) Declares that the package will need the root (or fakeroot) when either of the binary, binary-arch or binary-indep targets are called.
 This is how every tool behaved before this field was defined.',
           'no' => 'Declares that neither root nor fakeroot is required. Package builders (e.g. dpkg-buildpackage) may choose to invoke any target in debian/rules with an unprivileged user.'
         },
@@ -729,7 +729,7 @@ This is how every tool behaved before this field was defined.',
       },
       'X-Python-Version',
       {
-          'description' => 'This field specifies the versions of Python (not versions of Python 3) supported by the source package.
+        'description' => 'This field specifies the versions of Python (not versions of Python 3) supported by the source package.
 When not specified, they default to all currently supported Python (or Python 3) versions. For more detail,
 See L<python policy|https://www.debian.org/doc/packaging-manuals/python-policy/ch-module_packages.html#s-specifying_versions>',
         'migrate_from' => {
@@ -761,7 +761,7 @@ $new ;',
       },
       'X-Python3-Version',
       {
-          'description' => 'This field specifies the versions of Python 3 supported by the package. For more detail,
+        'description' => 'This field specifies the versions of Python 3 supported by the package. For more detail,
 See L<python policy|https://www.debian.org/doc/packaging-manuals/python-policy/ch-module_packages.html#s-specifying_versions>',
         'summary' => 'supported versions of Python3 ',
         'type' => 'leaf',
@@ -793,3 +793,4 @@ supported by the library',
   }
 ]
 ;
+
